# Copyright (C) 2026 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Spanner::V1::Spanner;

use strict;
use warnings;
use File::Spec;
use Protobuf;
use Protobuf::DescriptorPool;

our $VERSION = '0.02';

my ($vol, $dir, $file) = File::Spec->splitpath(__FILE__);
my $pb_path = File::Spec->catfile($dir, 'descriptors.pb');
if (-f $pb_path) {
    open my $fh, '<:raw', $pb_path or die "Cannot open $pb_path: $!";
    my $bytes = do { local $/; <$fh> };
    close $fh;
    my $pool = Protobuf::DescriptorPool->generated_pool;
    eval { $pool->add_serialized_file_descriptor_set($bytes) }
        || eval { $pool->add_serialized_file($bytes) };
}

1;
